@@ -6,7 +6,7 @@ TAG_STR = "tag:yaml.org,2002:str"
 def create_yaml(manifest, prefix, ingest_status):
 
     yaml = YAML()
-    with open(f"{prefix}.ga4gh.tmp", "w") as file:
+    with open(f"{prefix}.ga4gh.genomics.yml", "w") as file:
         yaml.dump(manifest, file)
     with open(f"{prefix}.runner", "w") as file:
         yaml.dump(ingest_status["run_instructions"], file)
