@@ -417,7 +417,7 @@ def extract_metadata(data, prefix, files, infile, ingest_status, log: Logger):
     ingest_files = [
         "nrm.vcf.gz",
         "tmp",
-        "ga4gh.tmp",
+        "ga4gh.genomics.yml",
         "runner",
         "yml",
         "ga4gh.yml",
