@@ -112,48 +112,44 @@ def get_test_yml(
     reportDate = str(get_date(signatures.get("Signature").get("ServerTime")))[0:10]
 
     yaml_file = {
-        "tests": [
+        "name": "Foundation Medicine",
+        "reference": "GRCh37",
+        "sourceFile": f"{base_xml_name}.xml",
+        "testType": sample.get("TestType"),
+        "indexedDate": indexedDate,
+        "receivedDate": receivedDate,
+        "collDate": collDate,
+        "reportDate": reportDate,
+        "reportID": trf,
+        "mrn": mrn,
+        "patientDOB": get_date(pmi.get("DOB")),
+        "patientLastName": pmi.get("LastName"),
+        "medFacilName": med_facil_info[0],
+        "medFacilID": med_facil_info[1],
+        "orderingMDName": ordering_md_info[0],
+        "orderingMDNPI": ordering_md_info[1],
+        "bodySite": variant_report.get("@tissue-of-origin"),
+        "bodySiteSystem": "http://foundation.com/bodySite",
+        "bodySiteDisplay": variant_report.get("@tissue-of-origin"),
+        "diagnosis": pmi.get("SubmittedDiagnosis"),
+        "diagnosisDisplay": pmi.get("SubmittedDiagnosis"),
+        "diagnosisSystem": "http://foundation.com/diagnosis",
+        "files": [
             {
-                "name": "Foundation Medicine",
-                "reference": "GRCh37",
-                "sourceFile": f"{base_xml_name}.xml",
-                "testType": sample.get("TestType"),
-                "indexedDate": indexedDate,
-                "receivedDate": receivedDate,
-                "collDate": collDate,
-                "reportDate": reportDate,
-                "reportID": trf,
-                "mrn": mrn,
-                "patientDOB": get_date(pmi.get("DOB")),
-                "patientLastName": pmi.get("LastName"),
-                "medFacilName": med_facil_info[0],
-                "medFacilID": med_facil_info[1],
-                "orderingMDName": ordering_md_info[0],
-                "orderingMDNPI": ordering_md_info[1],
-                "bodySite": variant_report.get("@tissue-of-origin"),
-                "bodySiteSystem": "http://foundation.com/bodySite",
-                "bodySiteDisplay": variant_report.get("@tissue-of-origin"),
-                "diagnosis": pmi.get("SubmittedDiagnosis"),
-                "diagnosisDisplay": pmi.get("SubmittedDiagnosis"),
-                "diagnosisSystem": "http://foundation.com/diagnosis",
-                "files": [
-                    {
-                        "type": "copyNumberVariant",
-                        "sequenceType": "somatic",
-                        "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.copynumber.csv",
-                    },
-                    {
-                        "type": "structuralVariant",
-                        "sequenceType": "somatic",
-                        "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.structural.csv",
-                    },
-                ],
-            }
-        ]
+                "type": "copyNumberVariant",
+                "sequenceType": "somatic",
+                "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.copynumber.csv",
+            },
+            {
+                "type": "structuralVariant",
+                "sequenceType": "somatic",
+                "fileName": f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.structural.csv",
+            },
+        ],
     }
 
     if write_vcf_to_manifest:
-        yaml_file["tests"][0]["files"].append(
+        yaml_file["files"].append(
             {
                 "type": "shortVariant",
                 "sequenceType": "somatic",
@@ -161,7 +157,7 @@ def get_test_yml(
             }
         )
 
-    yaml_file["tests"][0]["patientInfo"] = {
+    yaml_file["patientInfo"] = {
         "firstName": pmi.get("FirstName"),
         "lastName": pmi.get("LastName"),
         "gender": pmi.get("Gender").lower(),
@@ -169,7 +165,7 @@ def get_test_yml(
     }
 
     if mrn:
-        yaml_file["tests"][0]["patientInfo"]["identifiers"] = [
+        yaml_file["patientInfo"]["identifiers"] = [
             {
                 "codingSystem": "http://hl7.org/fhir/v2/0203",
                 "codingCode": "MR",
@@ -192,10 +188,8 @@ def get_test_yml(
 
         value = gw_loh.get("value", "").replace("%", "")
         # it is possible that value is "Units Not Reported"
-        yaml_file["tests"][0]["lossOfHeterozygosityScore"] = (
-            float(value) if is_number(value) else -1
-        )
-        yaml_file["tests"][0]["lossOfHeterozygosityStatus"] = values.get(
+        yaml_file["lossOfHeterozygosityScore"] = float(value) if is_number(value) else -1
+        yaml_file["lossOfHeterozygosityStatus"] = values.get(
             loh_alt.get("Name", "").lower(), "unknown"
         )
 
@@ -207,24 +201,20 @@ def get_test_yml(
             "unknown": "indeterminate",
         }
         microsatellite_dict = biomarkers["microsatellite-instability"]
-        yaml_file["tests"][0]["msi"] = values.get(microsatellite_dict.get("@status", "unknown"))
+        yaml_file["msi"] = values.get(microsatellite_dict.get("@status", "unknown"))
 
     if biomarkers and "tumor-mutation-burden" in biomarkers:
         tumor_dict = biomarkers["tumor-mutation-burden"]
-        yaml_file["tests"][0]["tmb"] = tumor_dict.get("@status", "unknown")
-        yaml_file["tests"][0]["tmbScore"] = float(tumor_dict.get("@score"))
+        yaml_file["tmb"] = tumor_dict.get("@status", "unknown")
+        yaml_file["tmbScore"] = float(tumor_dict.get("@score"))
 
     # adding non-human content fields
     if non_human_content != None:
-        yaml_file["tests"][0]["nonHumanContent"] = get_non_human_content(
-            non_human_content.get("non-human", "")
-        )
+        yaml_file["nonHumanContent"] = get_non_human_content(non_human_content.get("non-human", ""))
 
     if report_file:
         copyfile(report_file, f"{local_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf")
 
-        yaml_file["tests"][0][
-            "reportFile"
-        ] = f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf"
+        yaml_file["reportFile"] = f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf"
 
     return yaml_file
